clear; close all; clc;

K=50; Kt = 0.017; Kp = 1.6; T = 0.27; n = 1/3;
fs=20; Ts=1/fs;
s = tf('s'); z = tf('z');

A = [0 1; 0 -1/T];
B = [0; K*n^2/T];
C = [1 0];
%Controlabilidade em tempo contínuio
Cont = ctrb(A,B);
Posto_cont = rank(Cont)

[Phi, Gamma] = c2d(A,B,Ts); %discretização com ZOH
%Controlabilidade em tempo discreto
Cont_d = ctrb(Phi,Gamma);
Posto_cont_d = rank(Cont_d);

% Controle 1
%Deseja-se alocar os polos de MF tais que
% s = -zeta*wn +/- j*wd
% com zeta = sqrt(2)/2 e wn = 10
zeta = sqrt(2)/2; wn = 10;
wd = wn*sqrt(1-zeta^2);
s_1 = -zeta*wn + sqrt(-1)*wd; s_2 = s_1'; %par de polos de M.F. no plano-s
pc = exp(Ts*[s_1; s_2]); % %polos de M.F. no plano-z
Kc = place(Phi,Gamma,pc);
T_sim=3;
x1_0 = pi/2;
sim('servo_controle_1.slx');
subplot(1,2,1); plot(t,x_1,t,x_2);
t_n = (0:length(u)-1)*Ts;
subplot(1,2,2); stairs(t_n,u);


% Controle 2
pc_aug = exp(Ts*[s_1; s_2; -1.5]); % %polos de M.F. no plano-z
Phi_aug = [Phi, zeros(2,1); -C 1];
Gamma_aug = [Gamma; 0];
Kc_aug = place(Phi_aug, Gamma_aug, pc_aug);
Kc = Kc_aug(1:2);
Ki = -Kc_aug(3);
T_sim=40;
x1_0 = 0;
sim('servo_controle_2.slx');
figure;
subplot(1,2,1); plot(t,ref,t,x_1,t,x_2);
legend('referência','\theta_p','\omega_p')
t_n = (0:length(u)-1)*Ts;
subplot(1,2,2); stairs(t_n,u);

